@@ -132,7 +132,7 @@ dv_preds_vs_idv <- function(xpdb,
                             group    = 'ID',
                             type     = 'pls',
                             facets,
-                            title    = 'Observations, Individual predictions and Population predictions vs. @x | @run',
+                            title    = 'Observations, Individual and Population Predictions vs. @x | @run',
                             subtitle = 'Ofv: @ofv, Eps shrink: @epsshk',
                             caption  = '@dir',
                             tag      = NULL,
